import * as iam from '@aws-cdk/aws-iam';
import { AccessLevel } from './access-level';
export interface Action {
    url: string;
    description: string;
    accessLevel: string;
    resourceTypes?: any;
    conditions?: string[];
}
export interface Actions {
    [key: string]: Action;
}
export interface ResourceTypes {
    [key: string]: ResourceType;
}
export interface ResourceType {
    name: string;
    url: string;
    arn: string;
    conditionKeys: string[];
}
/**
 * Represents a statement in an IAM policy document.
 */
export declare class PolicyStatement extends iam.PolicyStatement {
    actions: Actions;
    add: (...actions: string[]) => void;
    servicePrefix: string;
    /**
     * Adds actions to the statement, matching an `AccessLevel` or regular expression.
     *
     * When no value is passed, all actions of the service will be added.
     */
    allActions(...rules: (AccessLevel | RegExp)[]): this;
    /**
     * Changes all subsequent additions to be set as notAction
     *
     * https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html
     */
    not(): this;
    /**
     * Allow the actions in this statement
     */
    allow(): this;
    /**
     * Deny the actions in this statement
     */
    deny(): this;
    /**
     * Adds a condition to the statement
     */
    if(key: string, value: any): this;
    /**
     * Limit statement to specified resources.
     *
     * To allow all resources, pass `*`
     */
    on(...arns: string[]): this;
    /**
     * JSON-ify the policy statement
     *
     * Also adds `*` to the list of resources, if not was manually added
     *
     * Used when JSON.stringify() is called
     */
    toStatementJson(): any;
}
